<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiFilter;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\GraphQl\Mutation;
use ApiPlatform\Metadata\GraphQl\Query;
use ApiPlatform\Metadata\GraphQl\QueryCollection;
use App\Filter\DateRangeFilter;
use App\State\NombreVentesProvider;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ApiResource (operations: [
    new GetCollection(
        uriTemplate: "/ventes/nombre",
        description: "Obtient le nombre de ventes en fonction de la date",
        name: "Nombre",
        provider: NombreVentesProvider::class
    ),
],
    paginationEnabled: false,
    graphQlOperations: [
        new QueryCollection(
            provider: NombreVentesProvider::class
        ),
    ]
)]
#[ApiFilter(DateRangeFilter::class)]
class NombreVentes
{
    private ?\DateTimeInterface $date = null;

    private ?int $quantite = null;


    public function getDate(): ?\DateTimeInterface
    {
        return $this->date;
    }

    public function setDate(\DateTimeInterface $date): self
    {
        $this->date = $date;

        return $this;
    }

    public function getQuantite(): ?int
    {
        return $this->quantite;
    }

    public function setQuantite(int $quantite): self
    {
        $this->quantite = $quantite;

        return $this;
    }
}
