<?php

namespace App\Entity;

use ApiPlatform\Action\NotFoundAction;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use App\State\RegionVentesProvider;

#[ApiResource(operations: [
    new GetCollection(
        uriTemplate: '/ventes/regions',
        description: 'Obtient le nombre de ventes par région',
        name: 'all',
        provider: RegionVentesProvider::class
    )
],
    paginationEnabled: false)]
class RegionVentes
{
    // Codes INSEE pour les régions métropolitaines et la Corse
    public const AUVERGNE_RHONE_ALPES = 84;
    public const BOURGOGNE_FRANCHE_COMTE = 27;
    public const BRETAGNE = 53;
    public const CENTRE_VAL_DE_LOIRE = 24;
    public const CORSE = 94;
    public const GRAND_EST = 44;
    public const HAUTS_DE_FRANCE = 32;
    public const ILE_DE_FRANCE = 11;
    public const NORMANDIE = 28;
    public const NOUVELLE_AQUITAINE = 75;
    public const OCCITANIE = 76;
    public const PAYS_DE_LA_LOIRE = 52;
    public const PROVENCE_ALPES_COTE_AZUR = 93;

    // Zéro pour les autres régions
    public const OUTRE_MER = 0;

    private int $region = -1;
    private int $count = 0;

    public function getRegion(): int
    {
        return $this->region;
    }

    public function setRegion(int $region): self
    {
        $this->region = $region;
        return $this;
    }

    public function getCount(): int
    {
        return $this->count;
    }

    public function setCount(int $count): self
    {
        $this->count = $count;
        return $this;
    }

    public function addCount(int $count): void
    {
        $this->count += $count;
    }
}
